#ifndef NT2_INCLUDE_FUNCTIONS_RSQRT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_RSQRT_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/rsqrt.hpp>

#endif
